<?php

namespace Teknisa\PLA\Modules\Medicao\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;

class SobraLimpa extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $dataSourceName;
    protected $entityManager;
    protected $environment;
    protected $crudService;

    public function __construct($crudService, $parameterBag, $entityManager, $dataSourceManager, $environment) {
        $this->crudService = $crudService;
        $this->entityManager = $entityManager;
        $this->dataSourceManager = $dataSourceManager;
        $this->environment = $environment;
    }

     public function updateSobraLimpa(DTO\Request $request, DTO\Response $response) {

        $name = $this->dataSourceName = 'sobra_limpa';
        $request = $this->crudService->buildDataSetIfRow($request, $name);

        $row = $request->getDataSet()->getRows();
        $row = (array) $row[0];

        $params = array(
            'nrcardapio' => $row['NRCARDAPIO'],
            'cdfilial'   => $row['CDFILIAL'],
            'nrorg'      => $this->environment->getNrOrgTrab(),  
        );

        $efetivos   = explode(',',$row['QTCOMEFETSL']);
        $comensais  = explode(',',$row['QTCOMESTICAR']);

        $cardadia = $this->entityManager->getRepository('\Teknisa\Model\Planejamento\Entities\Cardadia')->findBy($params);

        $cardadia[0]->setQtcomefetsl($efetivos[0]);
        $cardadia[0]->setQtcomesticar($comensais[0]);
        $cardadia[0]->setVrpesporperc($row['VRPESPORPERC']);
        $cardadia[0]->setQtsobrlimpca($row['QTSOBRLIMPCA']);
        $cardadia[0]->setCdmaiorpresl($row['CDMAIORPRESL']);
        $cardadia[0]->setCdfilauxprsl($row['CDFILAUXPRSL']);
        $this->entityManager->persist($cardadia[0]);
        $this->entityManager->flush();
    }

    public function setaDataSource(DTO\Request $request, DTO\Response $response) {

        $this->dataSourceName = 'sobra_limpa';
        $this->parameterBagColumns = array('CDFILIAL', 'CDSERVFILI', 'DATAINICIAL', 'DATAFINAL', 'NRORG');
        
        $conditions = $request->getFilterCriteria()->getConditions();   
        $filterCriteria = new FilterCriteria($this->dataSourceName);
        
        if ($conditions != []) {
            $cdfilial    = $conditions[0]['value'];
            $cdservfili  = $conditions[1]['value'];
            $dtcardapio  = $conditions[2]['value'];
            $dataInicial = $dtcardapio[0];
            $dataFinal   = $dtcardapio[1];
    
            $filterCriteria->addCondition('CDFILIAL', $cdfilial);
            $filterCriteria->addCondition('CDSERVFILI', $cdservfili);
            $filterCriteria->addCondition('NRORG', $this->environment->getNrOrgTrab());
            $filterCriteria->addCondition('DATAINICIAL', $dataInicial);
            $filterCriteria->addCondition('DATAFINAL', $dataFinal);
        }
        
        $newFilterCriteria = $this->crudService->populateParameterBag($filterCriteria, $this->parameterBagColumns);
        $dataSet = $this->dataSourceManager->findBy($newFilterCriteria);
    
        $response->addDataSet($dataSet);
    }

    public function retornaStripeSobraLimpa(DTO\Request $request, DTO\Response $response) {

        $mediaMesDia    = $this->retornaMediaMesDia($request);
        $maiorPct       = $this->retornaMaiorPct($request);
        $menorPct       = $this->retornaMenorPct($request);
        $meta           = $this->retornaMeta($request);


        $stripesobralimpa = array(
            'totrestinge' => $mediaMesDia['totrestinge'],
            'pemediaperc' => $mediaMesDia['pemediaperc'],
            'mediadia'    => $mediaMesDia['mediadia'],
            'maiorpct'    => $maiorPct['pemax'],
            'menorpct'    => $menorPct['pemin'],
            'meta'        => $meta['meta']
        );
        $response->addDataset(new DataSet('stripesobralimpa', array($stripesobralimpa)));
    }

    public function retornaMediaMesDia(DTO\Request $request) {

        $this->dataSourceName = 'resto_total_media_mes_dia_sobralimpa';
        $this->parameterBagColumns = array('CDFILIAL', 'NRORG', 'CDSERVFILI', 'DTMESCARD');
        $filterCriteria = $request->getFilterCriteria();
        $filterCriteria->setDataSourceName($this->dataSourceName);
        $newFilterCriteria = $this->crudService->populateParameterBag($filterCriteria, $this->parameterBagColumns);
        $dataSet = $this->dataSourceManager->findBy($newFilterCriteria);
        $rows = $dataSet->getRows();
        if (isset($rows[0])) {

            $totrestinge = $rows[0]['TOTRESTINGE'];
            $pemediaperc = $rows[0]['PEMEDIAPERC'];
            $mediadia    = $rows[0]['MEDIADIA'];

        } else {

            $totrestinge = 0;
            $pemediaperc = 0;
            $mediadia    = 0;
        }

        return array(
            'totrestinge' => $totrestinge,
            'pemediaperc' => $pemediaperc,
            'mediadia'    => $mediadia,
        );

    }

    public function retornaMaiorPct(DTO\Request $request) {
        $this->dataSourceName = 'resto_pemax_sobralimpa';
        $this->parameterBagColumns = array('CDFILIAL', 'NRORG', 'CDSERVFILI', 'DTMESCARD');
        $filterCriteria = $request->getFilterCriteria();
        $filterCriteria->setDataSourceName($this->dataSourceName);
        $newFilterCriteria = $this->crudService->populateParameterBag($filterCriteria, $this->parameterBagColumns);
        $dataSet = $this->dataSourceManager->findBy($newFilterCriteria);
        $rows = $dataSet->getRows();

        if (isset($rows[0])) {

            $pemax = $rows[0]['PEMAX'];

        } else {

            $pemax = 0;
        }

        return array(
            'pemax' => $pemax,
        );

    }

    public function retornaMenorPct(DTO\Request $request) {

        $this->dataSourceName = 'resto_pemin_sobralimpa';
        $this->parameterBagColumns = array('CDFILIAL', 'NRORG', 'CDSERVFILI', 'DTMESCARD');
        $filterCriteria = $request->getFilterCriteria();
        $filterCriteria->setDataSourceName($this->dataSourceName);
        $newFilterCriteria = $this->crudService->populateParameterBag($filterCriteria, $this->parameterBagColumns);
        $dataSet = $this->dataSourceManager->findBy($newFilterCriteria);
        $rows = $dataSet->getRows();

        if (isset($rows[0])) {

            $pemin = $rows[0]['PEMIN'];

        } else {

            $pemin = 0;
        }

        return array(
            'pemin' => $pemin,
        );

    }
    public function retornaMeta(DTO\Request $request) {

        $this->dataSourceName = 'resto_meta_sobralimpa';
        $this->parameterBagColumns = array('CDFILIAL', 'NRORG', 'CDSERVFILI', 'DTMESCARD');
        $filterCriteria = $request->getFilterCriteria();
        $filterCriteria->setDataSourceName($this->dataSourceName);
        $newFilterCriteria = $this->crudService->populateParameterBag($filterCriteria, $this->parameterBagColumns);
        $dataSet = $this->dataSourceManager->findBy($newFilterCriteria);
        $rows = $dataSet->getRows();

        if (isset($rows[0])) {

            $meta = $rows[0]['META'];

        } else {

            $meta = 0;
        }

        return array(
            'meta' => $meta,
        );

    }
}